@@ -1,20 +1,10 @@
+import numbers
 import urllib
 from datetime import date, datetime, time
-import numbers
 
+import pytz
 from requests import exceptions
 
-from ..metadata import (
-    Area,
-    Curve,
-    DataType,
-    Aggregation,
-    Filter,
-    ContractPeriod,
-    OHLCField,
-)
-from ..time import Frequency
-
 from ..exceptions import (
     ForbiddenError,
     HTTPError,
@@ -23,6 +13,20 @@ from ..exceptions import (
     UnauthorizedError,
     ValidationError,
 )
+from ..metadata import (
+    Area,
+    Curve,
+    CurveType,
+    DataType,
+    Aggregation,
+    Filter,
+    ContractPeriod,
+    OHLCField,
+)
+from ..time import (
+    Frequency,
+    timezone
+)
 
 
 def _urlencode(text, safe=''):
@@ -195,6 +199,24 @@ class BaseAPI:
         else:
             raise ValidationError(reason="Provide a time", parameter=name)
 
+    @staticmethod
+    def _add_time_list(params, name, var, required=False):
+        if (var is None or var == []) and not required:
+            return
+        if not isinstance(var, (list, tuple)):
+            var = [var]
+        for i in range(len(var)):
+            if isinstance(var[i], str):
+                continue
+            elif isinstance(var[i], time):
+                var[i] = var[i].isoformat(timespec='milliseconds')
+            else:
+                raise ValidationError(
+                    reason="Provide a time or a list of times",
+                    parameter=name,
+                )
+        params[name] = list(var)
+
     @staticmethod
     def _add_str(params, name, var, allowed_values=None, required=False):
         if var is None and not required:
@@ -301,6 +323,25 @@ class BaseAPI:
                 parameter=name
             )
 
+    @staticmethod
+    def _add_curve_type(params, name, var, required=False):
+        if var is None and not required:
+            return
+        if isinstance(var, str):
+            if not CurveType.is_valid_tag(var):
+                raise ValidationError(
+                    reason=f"Not a valid CurveType: '{var}'",
+                    parameter=name
+                )
+            params[name] = var
+        elif isinstance(var, CurveType):
+            params[name] = var.tag
+        else:
+            raise ValidationError(
+                reason=f"Not a valid CurveType: '{var}'",
+                parameter=name
+            )
+
     @staticmethod
     def _add_data_type(params, name, var, required=False):
         if var is None and not required:
@@ -320,6 +361,21 @@ class BaseAPI:
                 parameter=name
             )
 
+    @staticmethod
+    def _add_time_zone(params, name, var, required=False):
+        if var is None and not required:
+            return
+        if timezone._is_valid_timezone(var):
+            if isinstance(var, str):
+                params[name] = var
+            elif isinstance(var, pytz.tzinfo.BaseTzInfo):
+                params[name] = var.zone
+            return
+        raise ValidationError(
+            reason=f"Not a supported timezone: '{var}'",
+            parameter=name
+        )
+
     @staticmethod
     def _add_frequency(params, name, var, required=False):
         if var is None and not required:
