@@ -1,13 +1,13 @@
 from .base import BaseAPI
 
 from ..exceptions import ValidationError
-from ..metadata import Curve, CurveType, OHLCField
+from ..metadata import Curve, CurveType
 from ..parser.srmc import parse_srmc_response
 
-
 # Tuple of supported values for Curve.curve_type in the time series API
 CURVE_TYPES = (CurveType.OHLC,)
 
+
 class SrmcAPI(BaseAPI):
     """
     Operations for SRMC calculations in the API. Access these operations via
@@ -46,7 +46,8 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            unit=None):
         """
         Calculate historical short-run margincal costs (SRMC) for a
         continuous front contract.
@@ -89,6 +90,8 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a list of OHLC objects
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -104,9 +107,11 @@ class SrmcAPI(BaseAPI):
         self._add_int(params, "front", front, min=1, required=True)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
@@ -122,7 +127,8 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            unit=None):
         """
         Calculate historical short-run margincal costs (SRMC) for a specific
         contract, such as the year 2021, the month Jan 2021, etc.
@@ -166,6 +172,8 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a list of OHLC objects
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -181,9 +189,11 @@ class SrmcAPI(BaseAPI):
         self._add_date(params, "delivery", delivery, required=True)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
@@ -201,7 +211,8 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            unit=None):
         """
         Calculate historical short-run margincal costs (SRMC) for a continuous
         front contract and convert the result to a daily time series.
@@ -250,6 +261,8 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a ``timeseries`` object
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -266,9 +279,11 @@ class SrmcAPI(BaseAPI):
         self._add_fill(params, "fill", fill)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
@@ -285,7 +300,8 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            unit=None):
         """
         Calculate historical short-run margincal costs (SRMC) for a specific
         contract and convert it to a daily time series.
@@ -337,6 +353,8 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a ``timeseries`` object
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -353,9 +371,11 @@ class SrmcAPI(BaseAPI):
         self._add_fill(params, "fill", fill)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
@@ -368,7 +388,8 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            unit=None):
         """
         Calculate short-run margincal costs (SRMC) for all settlement prices
         from a trading day. Defaults to using OHLC data from the latest
@@ -409,6 +430,8 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a list of OHLC objects
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -421,9 +444,11 @@ class SrmcAPI(BaseAPI):
         self._add_date(params, "date", date)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
@@ -436,7 +461,9 @@ class SrmcAPI(BaseAPI):
             api2_tonne_to_mwh=None,
             carbon_emissions=None,
             efficiency=None,
-            carbon_tax_area=None):
+            carbon_tax_area=None,
+            time_zone=None,
+            unit=None):
         """
         Calculate short-run margincal costs (SRMC) for all settlement prices
         from a trading day, sort them, and merge/convert them to a continuous
@@ -480,6 +507,10 @@ class SrmcAPI(BaseAPI):
         :type efficiency: float, optional
         :param carbon_tax_area: Set an area to apply tax rules for.
         :type carbon_tax_area: Area, str, optional
+        :param time_zone: Set the timezone for the date-times
+        :type time_zone: TzInfo, optional
+        :param unit: Convert unit of data, defaults to curves unit
+        :type unit: str, optional
         :return: An SRMC object with a period-based series
         :rtype: :py:class:`energyquantified.data.SRMC`
         """
@@ -492,9 +523,12 @@ class SrmcAPI(BaseAPI):
         self._add_date(params, "date", date)
         self._add_number(params, "gas-therm-to-mwh", gas_therm_to_mwh)
         self._add_number(params, "api2-tonne-to-mwh", api2_tonne_to_mwh)
-        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01, max=1.0)
+        self._add_number(params, "carbon-emissions", carbon_emissions, min=0.01,
+                         max=1.0)
         self._add_number(params, "efficiency", efficiency, min=0.01, max=1.0)
         self._add_area(params, "carbon-tax-area", carbon_tax_area)
+        self._add_time_zone(params, "timezone", time_zone)
+        self._add_str(params, "unit", unit)
         # HTTP request
         response = self._get(url, params=params)
         return parse_srmc_response(response.json())
