@@ -1,11 +1,12 @@
-from collections import namedtuple
-from datetime import datetime
 import numbers
 import sys
+from collections import namedtuple
+from datetime import datetime
 
-from ..time import Resolution, Frequency
 from .base import Series
 from .timeseries import TimeseriesList, Timeseries, Value
+from ..time import Resolution, Frequency
+from ..utils.deprecation import deprecated
 
 
 class Period(namedtuple("Period", ("begin", "end", "value"))):
@@ -44,8 +45,8 @@ class Period(namedtuple("Period", ("begin", "end", "value"))):
         """
         Print this period-based series value.
         """
-        d0 = self.begin.isoformat(sep=' ')
-        d1 = self.end.isoformat(sep=' ')
+        d0 = self.begin.isoformat(sep=" ")
+        d1 = self.end.isoformat(sep=" ")
         v = self.value
         print(f"{d0}–{d1}\t{v:13.2f}", file=file)
 
@@ -58,14 +59,14 @@ class Period(namedtuple("Period", ("begin", "end", "value"))):
         :rtype: dict
         """
         return {
-            "begin": self.begin.isoformat(sep=' '),
-            "end": self.end.isoformat(sep=' '),
-            "v": self.value
+            "begin": self.begin.isoformat(sep=" "),
+            "end": self.end.isoformat(sep=" "),
+            "v": self.value,
         }
 
     def __str__(self):
-        d0 = self.begin.isoformat(sep=' ')
-        d1 = self.end.isoformat(sep=' ')
+        d0 = self.begin.isoformat(sep=" ")
+        d1 = self.end.isoformat(sep=" ")
         v = self.value
         return f"<Period: begin={d0}, end={d1}, value={v}>"
 
@@ -146,8 +147,8 @@ class CapacityPeriod(namedtuple("Period", ("begin", "end", "value", "installed")
         """
         Print this period-based series value.
         """
-        d0 = self.begin.isoformat(sep=' ')
-        d1 = self.end.isoformat(sep=' ')
+        d0 = self.begin.isoformat(sep=" ")
+        d1 = self.end.isoformat(sep=" ")
         v = self.value
         c = self.installed
         print(f"{d0}–{d1}\t{v:13.2f}\t{c:13.2f}", file=file)
@@ -161,15 +162,15 @@ class CapacityPeriod(namedtuple("Period", ("begin", "end", "value", "installed")
         :rtype: dict
         """
         return {
-            "begin": self.begin.isoformat(sep=' '),
-            "end": self.end.isoformat(sep=' '),
+            "begin": self.begin.isoformat(sep=" "),
+            "end": self.end.isoformat(sep=" "),
             "v": self.value,
             "c": self.installed,
         }
 
     def __str__(self):
-        d0 = self.begin.isoformat(sep=' ')
-        d1 = self.end.isoformat(sep=' ')
+        d0 = self.begin.isoformat(sep=" ")
+        d1 = self.end.isoformat(sep=" ")
         v = self.value
         c = self.installed
         return f"<Period: begin={d0}, end={d1}, value={v}, installed={c}>"
@@ -217,23 +218,31 @@ class Periodseries(Series):
     :type resolution: Resolution, optional
     :param instance: The instance, defaults to None
     :type instance: Instance, optional
+    :param unit: The unit, defaults to None
+    :type unit: str, optional
+    :param denominator: The denominator, defaults to None
+    :type denominator: str, optional
     :param data: A list of periods (Period or CapacityPeriod)
     :type data: list[]
     """
 
     def __init__(self, data=None, **kwargs):
         super().__init__(**kwargs)
-        assert isinstance(self.resolution, Resolution), (
-            "Periodseries.resolution is required"
-        )
+        assert isinstance(
+            self.resolution, Resolution
+        ), "Periodseries.resolution is required"
         self.data = data or []
 
     def __str__(self):
         items = []
         items.append(f"resolution={self.resolution}")
-        items.append(f"curve=\"{self.curve}\"")
+        items.append(f'curve="{self.curve}"')
         if self.instance:
             items.append(f"instance={self.instance}")
+        if self.unit:
+            items.append(f'unit="{self.unit}"')
+        if self.denominator:
+            items.append(f'denominator="{self.denominator}"')
         if self.has_data():
             items.append(f"begin=\"{self.begin().isoformat(sep=' ')}\"")
             items.append(f"end=\"{self.end().isoformat(sep=' ')}\"")
@@ -276,7 +285,9 @@ class Periodseries(Series):
         assert isinstance(field, str), "Must be a str"
         assert field in ("value", "installed"), "field must be 'value' or 'installed'"
         if field == "installed":
-            assert all(isinstance(p, CapacityPeriod) for p in self.data), "field='installed' requires a series of CapacityPeriods"
+            assert all(
+                isinstance(p, CapacityPeriod) for p in self.data
+            ), "field='installed' requires a series of CapacityPeriods"
         # Prepare conversion
         resolution = Resolution(frequency, self.resolution.timezone)
         if not self.has_data():
@@ -284,7 +295,9 @@ class Periodseries(Series):
                 curve=self.curve,
                 resolution=resolution,
                 instance=self.instance,
-                data=[]
+                unit=self.unit,
+                denominator=self.denominator,
+                data=[],
             )
         begin = resolution.floor(self.begin())
         end = self.end()
@@ -301,13 +314,57 @@ class Periodseries(Series):
             curve=self.curve,
             resolution=resolution,
             instance=self.instance,
-            data=data
+            unit=self.unit,
+            denominator=self.denominator,
+            data=data,
         )
         timeseries.set_name(self._name)
         return timeseries
 
-    def to_df(self, frequency=None, name=None, single_level_header=False, field="value"):
+    def to_pd_df(
+        self, frequency=None, name=None, single_level_header=False, field="value"
+    ):
         """
+        Alias for :meth:`Periodseries.to_pandas_dataframe`.
+
+        Convert this period-based to a ``pandas.DataFrame`` as a time series
+        in the given frequency.
+
+        Using :py:meth:`Periodseries.to_timeseries` to convert this
+        period-based series to a regular time series first. When periods
+        overlap the same step in the resulting time series, a weighted
+        average is calculated down to second-precision.
+
+        :param frequency: The frequency of the resulting ``pandas.DataFrame``\
+            time series
+        :type frequency: Frequency, required
+        :param name: Set a name for the column in the ``pandas.DataFrame``,\
+            defaults to ``value``
+        :type name: str, optional
+        :param single_level_header: Set to True to use single-level header\
+            in the DataFrame, defaults to False
+        :type single_level_header: boolean, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: pandas.DataFrame
+        :raises ImportError: When pandas is not installed on the system
+        """
+        return self.to_pandas_dataframe(
+            frequency=frequency,
+            name=name,
+            single_level_header=single_level_header,
+            field=field,
+        )
+
+    @deprecated(alt=to_pd_df)
+    def to_df(
+        self, frequency=None, name=None, single_level_header=False, field="value"
+    ):
+        """
+        DEPRECATED: Use ``to_pd_df`` instead.
+
         Alias for :meth:`Periodseries.to_dataframe`.
 
         Convert this period-based to a ``pandas.DataFrame`` as a time series
@@ -334,15 +391,16 @@ class Periodseries(Series):
         :rtype: pandas.DataFrame
         :raises ImportError: When pandas is not installed on the system
         """
-        return self.to_dataframe(
+        return self.to_pandas_dataframe(
             frequency=frequency,
             name=name,
             single_level_header=single_level_header,
             field=field,
         )
 
-    def to_dataframe(self, frequency=None, name=None,
-                     single_level_header=False, field="value"):
+    def to_pandas_dataframe(
+        self, frequency=None, name=None, single_level_header=False, field="value"
+    ):
         """
         Convert this period-based to a ``pandas.DataFrame`` as a time series
         in the given frequency.
@@ -372,12 +430,110 @@ class Periodseries(Series):
         assert isinstance(frequency, Frequency), "Must be a frequency"
         # Conversion
         timeseries = self.to_timeseries(frequency=frequency, field=field)
-        df = timeseries.to_dataframe(
-            name=name,
-            single_level_header=single_level_header
+        df = timeseries.to_pandas_dataframe(
+            name=name, single_level_header=single_level_header
         )
         return df
 
+    @deprecated(alt=to_pandas_dataframe)
+    def to_dataframe(
+        self, frequency=None, name=None, single_level_header=False, field="value"
+    ):
+        """
+        DEPRECATED: Use ``to_polars_dataframe`` instead.
+
+        Convert this period-based to a ``pandas.DataFrame`` as a time series
+        in the given frequency.
+
+        Using :py:meth:`Periodseries.to_timeseries` to convert this
+        period-based series to a regular time series first. When periods
+        overlap the same step in the resulting time series, a weighted
+        average is calculated down to second-precision.
+
+        :param frequency: The frequency of the resulting ``pandas.DataFrame``\
+            time series
+        :type frequency: Frequency, required
+        :param name: Set a name for the column in the ``pandas.DataFrame``,\
+            defaults to ``value``
+        :type name: str, optional
+        :param single_level_header: Set to True to use single-level header \
+            in the DataFrame, defaults to False
+        :type single_level_header: boolean, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: pandas.DataFrame
+        :raises ImportError: When pandas is not installed on the system
+        """
+        return self.to_pandas_dataframe(
+            frequency=frequency,
+            name=name,
+            single_level_header=single_level_header,
+            field=field,
+        )
+
+    def to_pl_df(self, frequency=None, name=None, field="value"):
+        """
+        Alias for :meth:`Periodseries.to_polars_dataframe`.
+
+        Convert this period-based to a ``polars.DataFrame`` as a time series
+        in the given frequency.
+
+        Using :py:meth:`Periodseries.to_timeseries` to convert this
+        period-based series to a regular time series first. When periods
+        overlap the same step in the resulting time series, a weighted
+        average is calculated down to second-precision.
+
+        :param frequency: The frequency of the resulting ``polars.DataFrame``\
+            time series
+        :type frequency: Frequency, required
+        :param name: Set a name for the column in the ``polars.DataFrame``,\
+            defaults to ``value``
+        :type name: str, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: polars.DataFrame
+        :raises ImportError: When polars is not installed on the system
+        """
+        return self.to_polars_dataframe(
+            frequency=frequency,
+            name=name,
+            field=field,
+        )
+
+    def to_polars_dataframe(self, frequency=None, name=None, field="value"):
+        """
+        Convert this period-based to a ``polars.DataFrame`` as a time series
+        in the given frequency.
+
+        Using :py:meth:`Periodseries.to_timeseries` to convert this
+        period-based series to a regular time series first. When periods
+        overlap the same step in the resulting time series, a weighted
+        average is calculated down to second-precision.
+
+        :param frequency: The frequency of the resulting ``polars.DataFrame``\
+            time series
+        :type frequency: Frequency, required
+        :param name: Set a name for the column in the ``polars.DataFrame``,\
+            defaults to ``value``
+        :type name: str, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: polars.DataFrame
+        :raises ImportError: When polars is not installed on the system
+        """
+        # Verify parameters
+        assert isinstance(frequency, Frequency), "Must be a frequency"
+        # Conversion
+        timeseries = self.to_timeseries(frequency=frequency, field=field)
+        df = timeseries.to_polars_dataframe(name=name)
+        return df
+
     def print(self, file=sys.stdout):
         """
         Utility method to print a period-based series to any file handle
@@ -389,6 +545,8 @@ class Periodseries(Series):
         if self.instance:
             print(f"  Instance: {self.instance}", file=file)
         print(f"  Resolution: {self.resolution}", file=file)
+        print(f"  Unit: {self.unit}", file=file)
+        print(f"  Denominator: {self.denominator}", file=file)
         print(f"", file=file)
         for d in self.data:
             d.print(file=file)
@@ -399,7 +557,9 @@ class _PeriodsToTimeseriesIterator:
     A period-based series iterator used for conversions to Timeseries objects.
     """
 
-    def __init__(self, periods=None, resolution=None, begin=None, end=None, field="value"):
+    def __init__(
+        self, periods=None, resolution=None, begin=None, end=None, field="value"
+    ):
         self.periods = [p for p in periods if p.end > begin and p.begin < end]
         self.resolution = resolution
         self.begin = begin
@@ -413,17 +573,20 @@ class _PeriodsToTimeseriesIterator:
         # Iterator stuff
         self.d = None
         self.p = None
+        self._is_first_iter = True
 
     def __iter__(self):
         # No periods available
         if not self.periods:
-            return []
-        # Get first period
-        self.d = self.begin
-        self.p = self.periods.pop(0)
+            return (p for p in self.periods)
         return self
 
     def __next__(self):
+        if self._is_first_iter:
+            # Get first period
+            self.d = self.begin
+            self.p = self.periods.pop(0)
+            self._is_first_iter = False
         # Get dates and current period
         p = self.p
         d0 = self.d
@@ -496,16 +659,12 @@ class _PeriodsToTimeseriesIterator:
         # Get sum of weight
         sum_weights = 1.0 * sum(weight for avail, weight in available_weights)
         # Get the mean value
-        return (
-            sum(avail * weight for avail, weight in available_weights)
-            / sum_weights
-        )
+        return sum(avail * weight for avail, weight in available_weights) / sum_weights
 
 
 # Period-based series list with helpers
 
 
-
 class PeriodseriesList(list):
     """
     A list of Periodseries objects. Have methods for converting them to a
@@ -544,8 +703,37 @@ class PeriodseriesList(list):
             for periodseries in self
         )
 
+    def to_pd_df(self, frequency=None, single_level_header=False, field="value"):
+        """
+        Alias for :meth:`Timeseries.to_pandas_dataframe`.
+
+        Convert this PeriodseriesList to a ``pandas.DataFrame`` where all time
+        series are placed in its own column and are lined up with the date-time
+        as index.
+
+        :param frequency: The frequency of the resulting time series'
+        :type frequency: Frequency, required
+        :param single_level_header: Set to True to use single-level header \
+            in the DataFrame, defaults to False
+        :type single_level_header: boolean, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: pandas.DataFrame
+        :raises ImportError: When pandas is not installed on the system
+        """
+        return self.to_pandas_dataframe(
+            frequency=frequency,
+            single_level_header=single_level_header,
+            field=field,
+        )
+
+    @deprecated(alt=to_pd_df)
     def to_df(self, frequency=None, single_level_header=False, field="value"):
         """
+        DEPRECATED: Use ``to_pd_df`` instead.
+
         Alias for :meth:`Timeseries.to_dataframe`.
 
         Convert this PeriodseriesList to a ``pandas.DataFrame`` where all time
@@ -564,13 +752,15 @@ class PeriodseriesList(list):
         :rtype: pandas.DataFrame
         :raises ImportError: When pandas is not installed on the system
         """
-        return self.to_dataframe(
+        return self.to_pandas_dataframe(
             frequency=frequency,
             single_level_header=single_level_header,
             field=field,
         )
 
-    def to_dataframe(self, frequency=None, single_level_header=False, field="value"):
+    def to_pandas_dataframe(
+        self, frequency=None, single_level_header=False, field="value"
+    ):
         """
         Convert this PeriodseriesList to a ``pandas.DataFrame`` where all time
         series are placed in its own column and are lined up with the date-time
@@ -592,10 +782,81 @@ class PeriodseriesList(list):
         assert isinstance(frequency, Frequency), "Must be a frequency"
         # Convert to time series then to data frame
         timeseries_list = self.to_timeseries(frequency=frequency, field=field)
-        return timeseries_list.to_dataframe(
+        return timeseries_list.to_pandas_dataframe(
             single_level_header=single_level_header
         )
 
+    @deprecated(alt=to_pandas_dataframe)
+    def to_dataframe(self, frequency=None, single_level_header=False, field="value"):
+        """
+        DEPRECATED: Use ``to_pandas_dataframe`` instead.
+
+        Convert this PeriodseriesList to a ``pandas.DataFrame`` where all time
+        series are placed in its own column and are lined up with the date-time
+        as index.
+
+        :param frequency: The frequency of the resulting time series'
+        :type frequency: Frequency, required
+        :param single_level_header: Set to True to use single-level header \
+            in the DataFrame, defaults to False
+        :type single_level_header: boolean, optional
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: pandas.DataFrame
+        :raises ImportError: When pandas is not installed on the system
+        """
+        return self.to_pandas_dataframe(
+            frequency=frequency,
+            single_level_header=single_level_header,
+            field=field,
+        )
+
+    def to_pl_df(self, frequency=None, field="value"):
+        """
+        Alias for :meth:`Timeseries.to_polars_dataframe`.
+
+        Convert this PeriodseriesList to a ``polars.DataFrame`` where all time
+        series are placed in its own column and are lined up with the date-time
+        as index.
+
+        :param frequency: The frequency of the resulting time series'
+        :type frequency: Frequency, required
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: polars.DataFrame
+        :raises ImportError: When polars is not installed on the system
+        """
+        return self.to_polars_dataframe(
+            frequency=frequency,
+            field=field,
+        )
+
+    def to_polars_dataframe(self, frequency=None, field="value"):
+        """
+        Convert this PeriodseriesList to a ``polars.DataFrame`` where all time
+        series are placed in its own column and are lined up with the date-time
+        as index.
+
+        :param frequency: The frequency of the resulting time series'
+        :type frequency: Frequency, required
+        :param field: Which period attribute to use when converting to timeseries.\
+            Options: 'value' or 'installed'. Defaults to 'value'.
+        :type field: str, optional
+        :return: A DataFrame
+        :rtype: polars.DataFrame
+        :raises ImportError: When polars is not installed on the system
+        """
+        # Verify parameters
+        assert isinstance(frequency, Frequency), "Must be a frequency"
+        # Convert to time series then to data frame
+        return self.to_timeseries(
+            frequency=frequency, field=field
+        ).to_polars_dataframe()
+
     def append(self, periodseries):
         _validate_periodseries(periodseries)
         return super().append(periodseries)
@@ -603,13 +864,13 @@ class PeriodseriesList(list):
     def extend(self, iterable):
         # Asserts
         _validate_periodseries_list(iterable)
-         # Perform operation
+        # Perform operation
         return super().extend(iterable)
 
     def insert(self, index, periodseries):
         # Asserts
         _validate_periodseries(periodseries)
-         # Perform operation
+        # Perform operation
         return super().insert(index, periodseries)
 
     def __add__(self, rhs):
