@@ -1,10 +1,10 @@
+from .metadata import parse_curve, parse_contract
+from .ohlc import parse_ohlc_list
+from .periodseries import parse_periodseries
+from .timeseries import parse_timeseries
 from ..data import SRMC, SRMCOptions, OHLCList
 from ..exceptions import ParseException
 from ..metadata import Area
-from .ohlc import parse_ohlc_list
-from .timeseries import parse_timeseries
-from .periodseries import parse_periodseries
-from .metadata import parse_curve, parse_contract
 
 
 def parse_srmc_response(json):
@@ -12,6 +12,9 @@ def parse_srmc_response(json):
     curve = json.get('curve')
     if curve is not None:
         curve = parse_curve(curve)
+    # Parse unit
+    unit = json.get("unit")
+    denominator = json.get("denominator")
     # Get contract
     contract = json.get('contract')
     if contract is not None:
@@ -26,6 +29,8 @@ def parse_srmc_response(json):
         ohlc = parse_ohlc_list(data)
         return SRMC(
             curve=curve,
+            unit=unit,
+            denominator=denominator,
             contract=contract,
             options=options,
             ohlc=OHLCList(ohlc)
@@ -36,6 +41,8 @@ def parse_srmc_response(json):
         timeseries = parse_timeseries(data)
         return SRMC(
             curve=curve,
+            unit=unit,
+            denominator=denominator,
             contract=contract,
             options=options,
             timeseries=timeseries
@@ -46,6 +53,8 @@ def parse_srmc_response(json):
         periodseries = parse_periodseries(data)
         return SRMC(
             curve=curve,
+            unit=unit,
+            denominator=denominator,
             contract=contract,
             options=options,
             periodseries=periodseries
@@ -56,6 +65,7 @@ def parse_srmc_response(json):
         "timeseries or periodseries, but got neither"
     )
 
+
 def parse_srmc_options(opts):
     # Check if there are any srmc options
     if not opts:
