@@ -29,8 +29,8 @@ How to generate the zone in this file
 
 import datetime
 
-from pytz.tzinfo import DstTzInfo
 from pytz import _tzinfo_cache
+from pytz.tzinfo import DstTzInfo
 
 
 def _build_europe_gas_day_tzinfo():
@@ -76,148 +76,216 @@ def _get_transition_info_cet():
     """
     return [
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET'),
-        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600), 'CEST'),
+        (datetime.timedelta(seconds=7200), datetime.timedelta(seconds=3600),
+         'CEST'),
         (datetime.timedelta(seconds=3600), datetime.timedelta(0), 'CET')
     ]
 
 
 def _get_transitions():
     """
-    All transitions for the CET time zone.
+    All transitions for the CET timezone.
     """
     return [
         datetime.datetime(1, 1, 1, 0, 0),
